@@ -15,12 +15,13 @@ from .models import (
     CardToken,
     Charge,
     ChargeList,
+    ErrorResponse,
     InstallmentOption,
     Order,
     OrderPayload,
+    PartialRefund,
     PixCharge,
     Refund,
-    PartialRefund,
 )
 
 
@@ -68,13 +69,27 @@ class BarteClient:
             )
         return cls._instance
 
+    def _extract_error_data(
+        self, json_response: Union[Dict[str, Any], List[Any]]
+    ) -> Optional[Dict[str, Any]]:
+        """Extract error data from API response if present."""
+        if isinstance(json_response, dict) and "errors" in json_response:
+            return json_response
+
+        if isinstance(json_response, list) and json_response:
+            first_item = json_response[0]
+            if isinstance(first_item, dict) and "errors" in first_item:
+                return first_item
+
+        return None
+
     def _request(
         self,
         method: str,
         path: str,
         params: Optional[Dict[str, Any]] = None,
         json: Optional[Dict[str, Any]] = None,
-    ) -> Dict[str, Any]:
+    ) -> Union[Dict[str, Any], List[Any], None]:
         """
         Private method to centralize HTTP requests.
 
@@ -85,19 +100,34 @@ class BarteClient:
             json: JSON body for POST, PATCH requests.
 
         Returns:
-            The response JSON as a dictionary.
+            The response JSON as a dictionary or list.
 
         Raises:
-            HTTPError: If the HTTP request returned an unsuccessful status code.
+            BarteError: If the API returns an error response with Barte error codes.
+            HTTPError: If the HTTP request returned an unsuccessful status code
+                       without a structured error response.
         """
         url = f"{self.base_url}{path}"
         response = self.session.request(method, url, params=params, json=json)
-        response.raise_for_status()
 
         if response.status_code == 204:
             return None
 
-        return response.json()
+        try:
+            json_response = response.json()
+        except ValueError:
+            response.raise_for_status()
+            return None
+
+        if error_data := self._extract_error_data(json_response):
+            error_response = from_dict(
+                data_class=ErrorResponse, data=error_data, config=DACITE_CONFIG
+            )
+            error_response.raise_exception(response=response)
+
+        response.raise_for_status()
+
+        return json_response
 
     def create_order(self, data: Union[Dict[str, Any], OrderPayload]) -> Order:
         """Create a new order"""
@@ -111,6 +141,11 @@ class BarteClient:
         json_response = self._request("GET", f"/v2/charges/{charge_id}")
         return from_dict(data_class=Charge, data=json_response, config=DACITE_CONFIG)
 
+    def get_order(self, order_id: str) -> Order:
+        """Get a specific order"""
+        json_response = self._request("GET", f"/v2/orders/{order_id}")
+        return from_dict(data_class=Order, data=json_response, config=DACITE_CONFIG)
+
     def list_charges(self, params: Optional[Dict[str, Any]] = None) -> ChargeList:
         """List all charges with optional filters"""
         json_response = self._request("GET", "/v2/charges", params=params)
@@ -122,9 +157,9 @@ class BarteClient:
         """Cancel a specific charge"""
         self._request("DELETE", f"/v2/charges/{charge_id}")
 
-    def create_buyer(self, buyer_data: Dict[str, Any]) -> Buyer:
+    def create_buyer(self, buyer_data: Dict[str, Any], version: str = "v2") -> Buyer:
         """Create a buyer"""
-        json_response = self._request("POST", "/v2/buyers", json=buyer_data)
+        json_response = self._request("POST", f"/{version}/buyers", json=buyer_data)
         return from_dict(data_class=Buyer, data=json_response, config=DACITE_CONFIG)
 
     def get_buyer(self, filters: Dict[str, Any]) -> BuyerList:
@@ -154,15 +189,25 @@ class BarteClient:
         json_response = self._request("GET", f"/v2/charges/{charge_id}")
         return from_dict(data_class=PixCharge, data=json_response, config=DACITE_CONFIG)
 
-    def refund_charge(self, charge_id: str, as_fraud: Optional[bool] = False) -> Refund:
-        """Refund a charge"""
+    def refund_charge(self, charge_id: str, as_fraud: Optional[bool] = False) -> Charge:
+        """Refund a charge
+
+        Raises:
+            BarteError: When the API returns an error response with Barte error codes.
+        """
         json_response = self._request(
             "PATCH", f"/v2/charges/{charge_id}/refund", json={"asFraud": as_fraud}
         )
-        return from_dict(data_class=Refund, data=json_response, config=DACITE_CONFIG)
+        return from_dict(data_class=Charge, data=json_response, config=DACITE_CONFIG)
 
-    def partial_refund_charge(self, charge_id: str, value: Decimal) -> List[Refund]:
-        """Refund a charge partialy"""
+    def partial_refund_charge(
+        self, charge_id: str, value: Decimal
+    ) -> List[PartialRefund]:
+        """Refund a charge partialy
+
+        Raises:
+            BarteError: When the API returns an error response with Barte error codes.
+        """
         json_response = self._request(
             "PATCH", f"/v2/charges/partial-refund/{charge_id}", json={"value": value}
         )
@@ -171,6 +216,14 @@ class BarteClient:
             for item in json_response
         ]
 
+    def get_refund(self, charge_id: str) -> List[Refund]:
+        """Get refund detail"""
+        json_response = self._request("GET", f"/v2/charges/partial-refund/{charge_id}")
+        return [
+            from_dict(data_class=Refund, data=item, config=DACITE_CONFIG)
+            for item in json_response
+        ]
+
     def get_installments(
         self, amount: Decimal, max_installments: int
     ) -> List[InstallmentOption]:
